@@ -15,7 +15,7 @@ require Exporter;
 @EXPORT = qw();
 @EXPORT_OK = qw();
 %EXPORT_TAGS = (all => [@EXPORT_OK]);
-$VERSION = '1.0205';
+$VERSION = '1.0300';
 
 
 has permanent_path => (
@@ -336,12 +336,9 @@ sub tokenize {
 
 	my $full_text = $text;
 		#contains the full body of text
-	my @sentences = split qr/(?|   (?<=(?<!\s[djms]r) (?<!\s[djms]rs) \.  |  \!  |  \?)  \s+\n?
-							   |   \s{3,}
-							   |   \s*\n\s*
+	my @sentences = split qr/(?|   (?<=(?<!\s[djms]r) (?<!\s[djms]rs) \.  |  \!  |  \?)  (?: (?=[A-Z])|\s+)
 							   |   (?: (?<![A-Za-z0-9-]) > \s+)+
 							   |   (?: ^\s+$ )
-							   |   (?: ^$)
 							 )/mix => $full_text;
 		# array of sentences
 
@@ -704,7 +701,7 @@ when multiple fragments are equivalent (i.e. they consist of the same list of to
 
 =head1 AUTHOR
 
-Faelin Landy (CPAN:FaeTheWolf) <faelin.landy@gmail.com>
+Faelin Landy (CPAN: FAELIN) L<faelin.landy@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
